# Intake Accumulo Plugin

[![Build Status](https://travis-ci.org/ContinuumIO/intake-accumulo.svg?branch=master)](https://travis-ci.org/ContinuumIO/intake-accumulo)
[![Documentation Status](https://readthedocs.org/projects/intake-accumulo/badge/?version=latest)](http://intake-accumulo.readthedocs.io/en/latest/?badge=latest)

This plugin is for the [Intake data loader library](http://intake.readthedocs.io/en/latest/).

### Installation

```
conda install -c intake intake-accumulo
```

### Caveats

This plugin has only been verified with Accumulo 1.5.2 and Thrift 0.11. Support
for other configurations is unverified at this time.
